==> deepin-boot-maker_5.6.5+dfsg.orig.tar.gz: deepin-boot-maker_5.6.5+dfsg/src/translations/deepin-boot-maker_bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="12"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="15"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>སྡུད་སྡེར་གྱི་བར་སྟོང་མི་འདང་བས། བར་སྟོང་འདང་ངེས་ཡོད་པའི་འགན་ལེན་བྱེད། </translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="18"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>སྡུད་སྡེར་ལེན་འཇོག་ནོར་བ། སྡུད་སྡེར་ཡང་བསྐྱར་འཇུག་པའམ་མ་ལག་བསྐྱར་སློང་བྱས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་གནང་དང་།</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="21"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>སྣང་བརྙན་སྡུད་གྲོལ་བྱེད་མི་ཐུབ། སྣང་བརྙན་ཡིག་ཆའི་md5ལ་ཞིབ་བཤེར་བྱས་ཏེ། སྣང་བརྙན་ཡིག་ཆ་ཆ་ཚང་ཡིན་པར་ཁག་ཐེག་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Internal Error</source>
        <translation>མ་ཤེས་པའི་ནོར་འཁྲུལ།</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>འགོ་སློང་སྡེར་མ་བཟོ་བའི་ཡོ་བྱད་ནི་རྒྱུད་ཁོངས་ཀྱི་ཤེལ་བརྙན་ཡིག་ཆ་དག་གསོག་འཇོག་བར་རྗས་ནང་འབྲི་བའི་ཡོ་བྱད་ཆུང་ངུ་ཞིག་ཡིན། </translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>འགོ་སློང་སྡེར་བཟོ་བའི་ཡོ་བྱད།</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>Drag an ISO image file here</source>
        <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་འདིར་འཇོག་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="144"/>
        <source>OR</source>
        <translation>ཡང་ན།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="89"/>
        <location filename="../app/view/isoselectview.cpp" line="163"/>
        <source>Select an ISO image file</source>
        <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་འདེམས་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="214"/>
        <source>Next</source>
        <translation>རྗེས་མ། </translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="300"/>
        <source>Reselect an ISO image file</source>
        <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་ཡང་བསྐྱར་འདེམས་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="237"/>
        <source>Illegal ISO image file</source>
        <translation>ཁྲིམས་འགལ་ISOཡིག་ཆ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="441"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>ISOཡིག་ཆ་བཤེར་འཇལ་བྱེད་བཞིན་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Burning</source>
        <translation>བཟོ་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="78"/>
        <source>Burning, please wait...</source>
        <translation>བཟོ་བཞིན་ཡོད་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="90"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>བཟོ་བའི་སྐབས་སུ་སྡུད་སྡེར་སྤོ་འབུད་དང་རྩིས་འཁོར་གློག་གསོད་བྱ་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="112"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>སྤོ་རུང་སྡུད་སྡེར།</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="221"/>
        <location filename="../libdbm/util/utils.cpp" line="365"/>
        <source>Removable disk</source>
        <translation>སྤོ་རུང་སྡུད་སྡེར།</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="118"/>
        <source>Boot Maker</source>
        <translation>འགོ་སློང་སྡེར་བཟོ་བའི་ཡོ་བྱད།</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="149"/>
        <source>Reboot now</source>
        <translation>ལམ་སེང་བསྐྱར་སློང་བྱེད།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="132"/>
        <source>Done</source>
        <translation>གྲུབ་ཟིན། </translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="66"/>
        <source>Successful</source>
        <translation>བཟོ་ཐུབ་སོང་།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="229"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>གནད་དོན་ལྡོག་སྐྱེལ་བྱེད་སྐབས་རང་འགུལ་ངང་ནོར་འཁྲུལ་ཉིན་ཐོ་སྐྱེལ་འཇོག་བྱེད་སྲིད། ང་ཚོའི་ཡར་རྒྱས་དང་སྐུ་ཉིད་ཀྱི་ལྡོག་སྐྱེལ་དང་རྒྱབ་སྐྱོར་བྲལ་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="230"/>
        <source>Submit Feedback</source>
        <translation>ལྡོག་སྐྱེལ་སྤྲོད་པ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="253"/>
        <source>After-Sale Services</source>
        <translation>བཙོངས་རྗེས་ཞབས་ཞུ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="269"/>
        <source>Close</source>
        <translation>སྒོ་བརྒྱབ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="277"/>
        <source>Sorry, process failed</source>
        <translation>བཟོ་མི་ཐུབ་པས། དགོངས་པ་མ་ཚོམ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="278"/>
        <source>Process failed</source>
        <translation>བཟོ་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>གཞི་གྲངས་གོམ་མཉམ་དང་ཉེན་མེད་སྤོ་འབུད་བྱེད་བཞིན་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="87"/>
        <source>Select a partition</source>
        <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="114"/>
        <source>Format the partition</source>
        <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="162"/>
        <source>Start</source>
        <translation>བཟོ་འགོ་ཚུགས་པ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="166"/>
        <source>Back</source>
        <translation>ཕྱིར་ལོག</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="222"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>རྣམ་གཞག་ཏུ་སྒྱུར་བ་འདིས་དབྱེ་ཁུལ་ཐོག་གི་གཞི་གྲངས་ཚང་མ་བསུབ་སྲིད། འོན་ཀྱང་བཟོ་ཚད་མཐོ་རུ་གཏོང་སྲིད་པས། གཏན་འཁེལ་རྗེས་མུ་མཐུད་བྱེད། </translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="318"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>རྣམ་གཞག་ཏུ་སྒྱུར་བ་འདིས་ཁུལ་དེའི་གཞི་གྲངས་ཚང་མ་བརླག་སྲིད་པས། གྲབས་ཉར་བྱས་རྗེས་མུ་མཐུད་བེད་སྤྱོད་བྱེད། </translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="335"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>སྡུད་སྡེར་གྱི་རྣམ་གཞག་ནོར་བས། FAT32རྣམ་གཞག་བེད་སྤྱད་བྱས་ཏེ་ཡང་བསྐྱར་རྣམ་གཞག་ཏུ་སྒྱུར་ནས་ཁུལ་དབྱེ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="147"/>
        <source>No disk available</source>
        <translation>སྤྱོད་རུང་བའི་སྡུད་སྡེར་རྙེད་མ་བྱུང་།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="316"/>
        <source>Format Partition</source>
        <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="319"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="320"/>
        <source>OK</source>
        <translation>གཏན་ཁེལ།</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_5.6.12+dfsg.orig.tar.gz: deepin-boot-maker_5.6.12+dfsg/src/translations/deepin-boot-maker_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation>སྡུད་སྡེར་རྣམ་གཞག་ནོར་འདུག རྣམ་གཞག་ཅན་དབྱེ་ཁུལ་འདེམས་པའམ་བདེ་འཇགས་ལྟེ་གནས་ཀྱི་USBརང་སྒྲུབ་ཞིབ་བཤེར་སྒོ་རྒྱག་རོགས།</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>སྡུད་སྡེར་རྣམ་གཞག་ནོར་འདུག་པས། ཡང་བསྐྱར་བཟོ་རོགས།</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>སྡུད་སྡེར་གྱི་བར་སྟོང་མི་འདང་བས། བར་སྟོང་འདང་ངེས་ཡོད་པའི་འགན་ལེན་བྱེད། </translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>སྡུད་སྡེར་ལེན་འཇོག་ནོར་བ། སྡུད་སྡེར་ཡང་བསྐྱར་འཇུག་པའམ་མ་ལག་བསྐྱར་སློང་བྱས་རྗེས་ཡང་བསྐྱར་ཚོད་ལྟ་གནང་དང་།</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>སྣང་བརྙན་སྡུད་གྲོལ་བྱེད་མི་ཐུབ། སྣང་བརྙན་ཡིག་ཆའི་md5ལ་ཞིབ་བཤེར་བྱས་ཏེ། སྣང་བརྙན་ཡིག་ཆ་ཆ་ཚང་ཡིན་པར་ཁག་ཐེག་བྱ་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>མ་ཤེས་པའི་ནོར་འཁྲུལ།</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>འགོ་སློང་སྡེར་མ་བཟོ་བའི་ཡོ་བྱད་ནི་རྒྱུད་ཁོངས་ཀྱི་ཤེལ་བརྙན་ཡིག་ཆ་དག་གསོག་འཇོག་བར་རྗས་ནང་འབྲི་བའི་ཡོ་བྱད་ཆུང་ངུ་ཞིག་ཡིན། </translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>འགོ་སློང་སྡེར་བཟོ་བའི་ཡོ་བྱད།</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="126"/>
        <source>Drag an ISO image file here</source>
        <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་འདིར་འཇོག་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="145"/>
        <source>OR</source>
        <translation>ཡང་ན།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="89"/>
        <location filename="../app/view/isoselectview.cpp" line="163"/>
        <source>Select an ISO image file</source>
        <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་འདེམས་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="211"/>
        <source>Next</source>
        <translation>རྗེས་མ། </translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="297"/>
        <source>Reselect an ISO image file</source>
        <translation>འོད་སྡེར་སྣང་བརྙན་ཡིག་ཆ་ཡང་བསྐྱར་འདེམས་རྒྱུ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="234"/>
        <source>Illegal ISO image file</source>
        <translation>ཁྲིམས་འགལ་ISOཡིག་ཆ།</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="438"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>ISOཡིག་ཆ་བཤེར་འཇལ་བྱེད་བཞིན་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="62"/>
        <source>Burning</source>
        <translation>བཟོ་བཞིན་པ།</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="78"/>
        <source>Burning, please wait...</source>
        <translation>བཟོ་བཞིན་ཡོད་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="90"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>བཟོ་བའི་སྐབས་སུ་སྡུད་སྡེར་སྤོ་འབུད་དང་རྩིས་འཁོར་གློག་གསོད་བྱ་མི་རུང་།</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="112"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>སྤོ་རུང་སྡུད་སྡེར།</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="223"/>
        <location filename="../libdbm/util/utils.cpp" line="369"/>
        <source>Removable disk</source>
        <translation>སྤོ་རུང་སྡུད་སྡེར།</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="118"/>
        <source>Boot Maker</source>
        <translation>འགོ་སློང་སྡེར་བཟོ་བའི་ཡོ་བྱད།</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="137"/>
        <source>Reboot now</source>
        <translation>ལམ་སེང་བསྐྱར་སློང་བྱེད།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="120"/>
        <source>Done</source>
        <translation>གྲུབ་ཟིན། </translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="68"/>
        <source>Successful</source>
        <translation>བཟོ་ཐུབ་སོང་།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="217"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>གནད་དོན་ལྡོག་སྐྱེལ་བྱེད་སྐབས་རང་འགུལ་ངང་ནོར་འཁྲུལ་ཉིན་ཐོ་སྐྱེལ་འཇོག་བྱེད་སྲིད། ང་ཚོའི་ཡར་རྒྱས་དང་སྐུ་ཉིད་ཀྱི་ལྡོག་སྐྱེལ་དང་རྒྱབ་སྐྱོར་བྲལ་ཐབས་མེད།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="218"/>
        <source>Submit Feedback</source>
        <translation>ལྡོག་སྐྱེལ་སྤྲོད་པ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="241"/>
        <source>After-Sale Services</source>
        <translation>བཙོངས་རྗེས་ཞབས་ཞུ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="254"/>
        <source>Close</source>
        <translation>སྒོ་བརྒྱབ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="262"/>
        <source>Sorry, process failed</source>
        <translation>བཟོ་མི་ཐུབ་པས། དགོངས་པ་མ་ཚོམ།</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="263"/>
        <source>Process failed</source>
        <translation>བཟོ་མི་ཐུབ།</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>གཞི་གྲངས་གོམ་མཉམ་དང་ཉེན་མེད་སྤོ་འབུད་བྱེད་བཞིན་པས། ཏོག་ཙམ་སྒུག་རོགས་གནང་།</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="95"/>
        <source>Select a partition</source>
        <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="122"/>
        <source>Format the partition</source>
        <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="171"/>
        <source>Start</source>
        <translation>བཟོ་འགོ་ཚུགས་པ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="175"/>
        <source>Back</source>
        <translation>ཕྱིར་ལོག</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>རྣམ་གཞག་ཏུ་སྒྱུར་བ་འདིས་དབྱེ་ཁུལ་ཐོག་གི་གཞི་གྲངས་ཚང་མ་བསུབ་སྲིད། འོན་ཀྱང་བཟོ་ཚད་མཐོ་རུ་གཏོང་སྲིད་པས། གཏན་འཁེལ་རྗེས་མུ་མཐུད་བྱེད། </translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="368"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>རྣམ་གཞག་ཏུ་སྒྱུར་བ་འདིས་ཁུལ་དེའི་གཞི་གྲངས་ཚང་མ་བརླག་སྲིད་པས། གྲབས་ཉར་བྱས་རྗེས་མུ་མཐུད་བེད་སྤྱོད་བྱེད། </translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="402"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>སྡུད་སྡེར་གྱི་རྣམ་གཞག་ནོར་བས། FAT32རྣམ་གཞག་བེད་སྤྱད་བྱས་ཏེ་ཡང་བསྐྱར་རྣམ་གཞག་ཏུ་སྒྱུར་ནས་ཁུལ་དབྱེ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="156"/>
        <source>No disk available</source>
        <translation>སྤྱོད་རུང་བའི་སྡུད་སྡེར་རྙེད་མ་བྱུང་།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="365"/>
        <source>Format Partition</source>
        <translation>ཁུལ་དགར་རྣམ་གཞག་བཟོ་བ།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="372"/>
        <source>Cancel</source>
        <translation>ཕྱིར་འཐེན།</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="374"/>
        <source>OK</source>
        <translation>གཏན་ཁེལ།</translation>
    </message>
</context>
</TS>
